aboutsummaryrefslogtreecommitdiff
path: root/http_global.go
diff options
context:
space:
mode:
Diffstat (limited to 'http_global.go')
-rw-r--r--http_global.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/http_global.go b/http_global.go
index 20a1cbc..f793c24 100644
--- a/http_global.go
+++ b/http_global.go
@@ -3,10 +3,10 @@
package main
-// global_data is passed as "global" when rendering HTML templates.
-var global_data = map[string]any{
- "server_public_key_string": &server_public_key_string,
- "server_public_key_fingerprint": &server_public_key_fingerprint,
+// globalData is passed as "global" when rendering HTML templates.
+var globalData = map[string]any{
+ "server_public_key_string": &serverPubkeyString,
+ "server_public_key_fingerprint": &serverPubkeyFP,
"forge_version": VERSION,
// Some other ones are populated after config parsing
}